
/*
 * Copyright (C) 2002-2003 Stefan Holst
 * Copyright (C) 2004-2005 Maximilian Schwerin
 *
 * This file is part of oxine a free media player.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * $Id: mediamarks.h 2347 2007-06-27 12:12:28Z mschwerin $
 *
 */

#ifndef HAVE_MEDIAMARKS_H
#define HAVE_MEDIAMARKS_H


bool mediamarks_read (filelist_t * filelist);


bool mediamarks_write (filelist_t *filelist);


bool favorites_read (filelist_t * filelist);


#endif /* HAVE_MEDIAMARKS_H */
